==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Draw/Text/ts/Text_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs_CZ">
<context>
    <name>Dialog</name>
    <message>
        <location filename="../TextDialog/CharacterMapDialog.ui" line="+14"/>
        <source>Character Map</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Text</name>
    <message>
        <location filename="../Text.js" line="+88"/>
        <source>Position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../Text.ui" line="+17"/>
        <source>Contents:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Height:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Angle:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../TextInit.js" line="+2"/>
        <source>&amp;Text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw text</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TextDialog</name>
    <message>
        <location filename="../TextDialog/TextDialog.js" line="+242"/>
        <source>Default value:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+260"/>
        <source>&amp;Undo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&amp;Redo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Cu&amp;t</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&amp;Copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&amp;Paste</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Bold</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&amp;Italic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+20"/>
        <source>&amp;Subscript</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Superscript</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+18"/>
        <source>&amp;Color...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&amp;Special Characters...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+310"/>
        <source>Others...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+131"/>
        <source>Degree</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plus-Minus</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Diameter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Almost equal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Multiplication</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Division</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Delta</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Pi</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Identity</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Not equal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Ohm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Omega</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Squared</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Cubed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>No-break space</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../TextDialog/TextDialog.ui" line="+14"/>
        <source>Text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Main Font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Height:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Text Height in Drawing Units</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+18"/>
        <location line="+213"/>
        <source>Bold</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-206"/>
        <location line="+219"/>
        <source>Italic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-205"/>
        <source>Text fits on one line and has no formatting</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Simple text
(one line, no formatting)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Rich Text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Paste</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+115"/>
        <source>Ctrl+B</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Ctrl+I</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+40"/>
        <source>Insert Symbol...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+43"/>
        <source>Source</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Attribute Details</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Tag:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Prompt:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Value:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+42"/>
        <source>Text Geometry</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Line spacing factor:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Line Spacing Factor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Angle:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Rotation Angle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+25"/>
        <source>Alignment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+311"/>
        <source>Bottom Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+29"/>
        <source>Bottom Center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-261"/>
        <source>Top Center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+29"/>
        <source>Middle Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+116"/>
        <source>Base Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-177"/>
        <source>Top Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+206"/>
        <source>Base Center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+29"/>
        <source>Base Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-116"/>
        <source>Middle Center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+203"/>
        <source>Bottom Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-174"/>
        <source>Middle Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-58"/>
        <source>Top Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+291"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+13"/>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Draw/Text/ts/Text_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>Dialog</name>
    <message>
        <location filename="../TextDialog/CharacterMapDialog.ui" line="+14"/>
        <source>Character Map</source>
        <translation>Mapa znaků</translation>
    </message>
</context>
<context>
    <name>Text</name>
    <message>
        <location filename="../Text.js" line="+88"/>
        <source>Position</source>
        <translation>Umístění</translation>
    </message>
    <message>
        <location filename="../Text.ui" line="+17"/>
        <source>Contents:</source>
        <translation>Obsah:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Height:</source>
        <translation>Výška:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Angle:</source>
        <translation>Úhel:</translation>
    </message>
    <message>
        <location filename="../TextInit.js" line="+2"/>
        <source>&amp;Text</source>
        <translation>&amp;Text</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw text</source>
        <translation>Vykreslit text</translation>
    </message>
</context>
<context>
    <name>TextDialog</name>
    <message>
        <location filename="../TextDialog/TextDialog.js" line="+242"/>
        <source>Default value:</source>
        <translation>Výchozí hodnota:</translation>
    </message>
    <message>
        <location line="+266"/>
        <source>&amp;Undo</source>
        <translation>&amp;Zpět</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&amp;Redo</source>
        <translation>Z&amp;novu</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Cu&amp;t</source>
        <translation>Vyjmou&amp;t</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&amp;Copy</source>
        <translation>&amp;Kopírovat</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&amp;Paste</source>
        <translation>&amp;Vložit</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Bold</source>
        <translation>&amp;Tučné</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&amp;Italic</source>
        <translation>&amp;Kurzíva</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>&amp;Subscript</source>
        <translation>&amp;Dolní index</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Superscript</source>
        <translation>&amp;Horní index</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>&amp;Color...</source>
        <translation>&amp;Barva...</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&amp;Special Characters...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+305"/>
        <source>Others...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+131"/>
        <source>Degree</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plus-Minus</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Diameter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Almost equal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Multiplication</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Division</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Delta</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Pi</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Identity</source>
        <translation type="unfinished">Identita</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Not equal</source>
        <translation>Není rovno</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Ohm</source>
        <translation>Ohm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Omega</source>
        <translation>Omega</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Squared</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Cubed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>No-break space</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../TextDialog/TextDialog.ui" line="+14"/>
        <source>Text</source>
        <translation>Text</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Main Font</source>
        <translation>Hlavní písmo</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Height:</source>
        <translation type="unfinished">Výška:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Text Height in Drawing Units</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+18"/>
        <location line="+268"/>
        <source>Bold</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-261"/>
        <location line="+274"/>
        <source>Italic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-260"/>
        <source>Text fits on one line and has no formatting</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Simple text
(one line, no formatting)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Rich Text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Copy</source>
        <translation>Kopírovat</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Paste</source>
        <translation>Vložit</translation>
    </message>
    <message>
        <location line="+170"/>
        <source>Ctrl+B</source>
        <translation>Ctrl+B</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <location line="+40"/>
        <source>Insert Symbol...</source>
        <translation>Vložit symbol</translation>
    </message>
    <message>
        <location line="+43"/>
        <source>Source</source>
        <translation>Zdroj</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Attribute Details</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Tag:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Prompt:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Value:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+42"/>
        <source>Text Geometry</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Line spacing factor:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Line Spacing Factor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Angle:</source>
        <translation type="unfinished">Úhel:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Rotation Angle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+25"/>
        <source>Alignment</source>
        <translation>Zarovnání</translation>
    </message>
    <message>
        <location line="+311"/>
        <source>Bottom Left</source>
        <translation>Vlevo dole</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>Bottom Center</source>
        <translation>Dole uprostřed</translation>
    </message>
    <message>
        <location line="-261"/>
        <source>Top Center</source>
        <translation>Nahoře uprostřed</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>Middle Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+116"/>
        <source>Base Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-177"/>
        <source>Top Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+206"/>
        <source>Base Center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+29"/>
        <source>Base Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-116"/>
        <source>Middle Center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+203"/>
        <source>Bottom Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-174"/>
        <source>Middle Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-58"/>
        <source>Top Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+291"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+13"/>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
